@@ -270,21 +270,27 @@ ma_r_bb <- ma_r_barebones <- function(r, n, n_adj = NULL, sample_id = NULL, cite
      ci <- setNames(c(ci), colnames(ci))
      cr <- setNames(c(cr), colnames(cr))
 
-     barebones <- data.frame(t(c(k = k,
-                                 N = N,
-                                 mean_r = mean_r_xy,
-                                 var_r = var_r,
-                                 var_e = var_e,
-                                 var_res = var_res,
-                                 sd_r = sd_r,
-                                 se_r = se_r,
-                                 sd_e = sd_e,
-                                 sd_res = sd_res,
-                                 ci, cr)), stringsAsFactors = FALSE)
+     barebones <-
+          as.data.frame(
+               as.list(
+                    c(k = k,
+                      N = N,
+                      mean_r = mean_r_xy,
+                      var_r = var_r,
+                      var_e = var_e,
+                      var_res = var_res,
+                      sd_r = sd_r,
+                      se_r = se_r,
+                      sd_e = sd_e,
+                      sd_res = sd_res,
+                      ci, cr)
+                    ),
+               stringsAsFactors = FALSE)
 
      class(barebones) <- c("ma_table", class(barebones))
      attributes(barebones) <- append(attributes(barebones), list(ma_type = "r_bb"))
 
+     # TODO: Drop this and just return the requested one
      list(meta = list(barebones = barebones,
                       individual_correction = NULL,
                       artifact_distribution = NULL),
